==> analitza-17.12.3.tar.xz: analitza-17.12.3/analitzaplot/tests/plotsdictionarymodeltest.h <==
/*************************************************************************************
 *  Copyright (C) 2012 by Aleix Pol Gonzalez <aleixpol@kde.org>                      *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#ifndef ANALITZATEST_H
#define ANALITZATEST_H

#include <QObject>

/**
    @author Aleix Pol
*/
namespace Analitza { class Variables; }

class PlotsDictionaryModelTest : public QObject
{
Q_OBJECT
    public:
        PlotsDictionaryModelTest(QObject *parent = 0);
        ~PlotsDictionaryModelTest();

    private Q_SLOTS:
        void testDictionaries();
};

#endif

==> analitza_19.12.3.orig.tar.xz: analitza-19.12.3/analitzaplot/tests/plotsdictionarymodeltest.h <==
/*************************************************************************************
 *  Copyright (C) 2012 by Aleix Pol Gonzalez <aleixpol@kde.org>                      *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#ifndef PLOTSDICTIONARYMODELTEST_H
#define PLOTSDICTIONARYMODELTEST_H

#include <QObject>

/**
    @author Aleix Pol
*/
namespace Analitza { class Variables; }

class PlotsDictionaryModelTest : public QObject
{
Q_OBJECT
    public:
        PlotsDictionaryModelTest(QObject *parent = nullptr);
        ~PlotsDictionaryModelTest();

    private Q_SLOTS:
        void testDictionaries();
};

#endif
